@@ -2,17 +2,19 @@
 #------------------------------------------
 # Use rlog utility.
 #------------------------------------------
+use strict;
 use Rcs;
 
-Rcs->quiet(1);
-
 my $obj = Rcs->new;
+
+# call quiet and bindir as objest methods
+$obj->quiet(1);
 $obj->bindir('/usr/bin');
 
 print "Quiet mode set\n" if Rcs->quiet;
 
-$obj->rcsdir("./project_tree/archive");
-$obj->workdir("./project_tree/src");
-$obj->file("cornholio.pl");
+$obj->rcsdir("./project/RCS");
+$obj->workdir("./project/src");
+$obj->file("testfile");
 
-print $obj->rlog;
+print $obj->rlog('-h');
